==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/UpstreamResolversFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class UpstreamResolversFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent<A>{
  public UpstreamResolversFluentImpl() {
  }
  public UpstreamResolversFluentImpl(io.fabric8.openshift.api.model.operator.v1.UpstreamResolvers instance) {
    this.withPolicy(instance.getPolicy()); 
    this.withUpstreams(instance.getUpstreams()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String policy;
  private java.util.List<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> upstreams =  new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getPolicy() {
    return this.policy;
  }
  public A withPolicy(java.lang.String policy) {
    this.policy=policy; return (A) this;
  }
  public java.lang.Boolean hasPolicy() {
    return this.policy != null;
  }
  
  /**
   * Method is deprecated. use withPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewPolicy(java.lang.String arg0) {
    return (A)withPolicy(new String(arg0));
  }
  public A addToUpstreams(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.Upstream item) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();}
    io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").add(index >= 0 ? index : _visitables.get("upstreams").size(), builder);this.upstreams.add(index >= 0 ? index : upstreams.size(), builder); return (A)this;
  }
  public A setToUpstreams(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.Upstream item) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();}
    io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);
    if (index < 0 || index >= _visitables.get("upstreams").size()) { _visitables.get("upstreams").add(builder); } else { _visitables.get("upstreams").set(index, builder);}
    if (index < 0 || index >= upstreams.size()) { upstreams.add(builder); } else { upstreams.set(index, builder);}
     return (A)this;
  }
  public A addToUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... items) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();}
    for (io.fabric8.openshift.api.model.operator.v1.Upstream item : items) {io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").add(builder);this.upstreams.add(builder);} return (A)this;
  }
  public A addAllToUpstreams(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.Upstream> items) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();}
    for (io.fabric8.openshift.api.model.operator.v1.Upstream item : items) {io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").add(builder);this.upstreams.add(builder);} return (A)this;
  }
  public A removeFromUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... items) {
    for (io.fabric8.openshift.api.model.operator.v1.Upstream item : items) {io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").remove(builder);if (this.upstreams != null) {this.upstreams.remove(builder);}} return (A)this;
  }
  public A removeAllFromUpstreams(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.Upstream> items) {
    for (io.fabric8.openshift.api.model.operator.v1.Upstream item : items) {io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").remove(builder);if (this.upstreams != null) {this.upstreams.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromUpstreams(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> predicate) {
    if (upstreams == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> each = upstreams.iterator();
    final List visitables = _visitables.get("upstreams");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildUpstreams instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.Upstream> getUpstreams() {
    return build(upstreams);
  }
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.Upstream> buildUpstreams() {
    return build(upstreams);
  }
  public io.fabric8.openshift.api.model.operator.v1.Upstream buildUpstream(java.lang.Integer index) {
    return this.upstreams.get(index).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.Upstream buildFirstUpstream() {
    return this.upstreams.get(0).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.Upstream buildLastUpstream() {
    return this.upstreams.get(upstreams.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.Upstream buildMatchingUpstream(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder item: upstreams) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingUpstream(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder item: upstreams) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withUpstreams(java.util.List<io.fabric8.openshift.api.model.operator.v1.Upstream> upstreams) {
    if (this.upstreams != null) { _visitables.get("upstreams").removeAll(this.upstreams);}
    if (upstreams != null) {this.upstreams = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>(); for (io.fabric8.openshift.api.model.operator.v1.Upstream item : upstreams){this.addToUpstreams(item);}} else { this.upstreams = null;} return (A) this;
  }
  public A withUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... upstreams) {
    if (this.upstreams != null) {this.upstreams.clear();}
    if (upstreams != null) {for (io.fabric8.openshift.api.model.operator.v1.Upstream item :upstreams){ this.addToUpstreams(item);}} return (A) this;
  }
  public java.lang.Boolean hasUpstreams() {
    return upstreams != null && !upstreams.isEmpty();
  }
  public A addNewUpstream(java.lang.String address,java.lang.Integer port,java.lang.String type) {
    return (A)addToUpstreams(new Upstream(address, port, type));
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> addNewUpstream() {
    return new io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluentImpl.UpstreamsNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> addNewUpstreamLike(io.fabric8.openshift.api.model.operator.v1.Upstream item) {
    return new io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluentImpl.UpstreamsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> setNewUpstreamLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.Upstream item) {
    return new io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluentImpl.UpstreamsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> editUpstream(java.lang.Integer index) {
    if (upstreams.size() <= index) throw new RuntimeException("Can't edit upstreams. Index exceeds size.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> editFirstUpstream() {
    if (upstreams.size() == 0) throw new RuntimeException("Can't edit first upstreams. The list is empty.");
    return setNewUpstreamLike(0, buildUpstream(0));
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> editLastUpstream() {
    int index = upstreams.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last upstreams. The list is empty.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> editMatchingUpstream(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> predicate) {
    int index = -1;
    for (int i=0;i<upstreams.size();i++) { 
    if (predicate.test(upstreams.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching upstreams. No match found.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UpstreamResolversFluentImpl that = (UpstreamResolversFluentImpl) o;
    if (policy != null ? !policy.equals(that.policy) :that.policy != null) return false;
    if (upstreams != null ? !upstreams.equals(that.upstreams) :that.upstreams != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(policy,  upstreams,  additionalProperties,  super.hashCode());
  }
  public class UpstreamsNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.UpstreamFluentImpl<io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<N>> implements io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    UpstreamsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.Upstream item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(this, item);
    }
    UpstreamsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) UpstreamResolversFluentImpl.this.setToUpstreams(index,builder.build());
    }
    public N endUpstream() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/UpstreamResolversFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class UpstreamResolversFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent<A>{
  public UpstreamResolversFluentImpl() {
  }
  public UpstreamResolversFluentImpl(io.fabric8.openshift.api.model.operator.v1.UpstreamResolvers instance) {
    this.withPolicy(instance.getPolicy()); 
    this.withUpstreams(instance.getUpstreams()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String policy;
  private java.util.List<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> upstreams =  new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getPolicy() {
    return this.policy;
  }
  public A withPolicy(java.lang.String policy) {
    this.policy=policy; return (A) this;
  }
  public java.lang.Boolean hasPolicy() {
    return this.policy != null;
  }
  
  /**
   * Method is deprecated. use withPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewPolicy(java.lang.String arg0) {
    return (A)withPolicy(new String(arg0));
  }
  public A addToUpstreams(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.Upstream item) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();}
    io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").add(index >= 0 ? index : _visitables.get("upstreams").size(), builder);this.upstreams.add(index >= 0 ? index : upstreams.size(), builder); return (A)this;
  }
  public A setToUpstreams(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.Upstream item) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();}
    io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);
    if (index < 0 || index >= _visitables.get("upstreams").size()) { _visitables.get("upstreams").add(builder); } else { _visitables.get("upstreams").set(index, builder);}
    if (index < 0 || index >= upstreams.size()) { upstreams.add(builder); } else { upstreams.set(index, builder);}
     return (A)this;
  }
  public A addToUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... items) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();}
    for (io.fabric8.openshift.api.model.operator.v1.Upstream item : items) {io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").add(builder);this.upstreams.add(builder);} return (A)this;
  }
  public A addAllToUpstreams(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.Upstream> items) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder>();}
    for (io.fabric8.openshift.api.model.operator.v1.Upstream item : items) {io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").add(builder);this.upstreams.add(builder);} return (A)this;
  }
  public A removeFromUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... items) {
    for (io.fabric8.openshift.api.model.operator.v1.Upstream item : items) {io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").remove(builder);if (this.upstreams != null) {this.upstreams.remove(builder);}} return (A)this;
  }
  public A removeAllFromUpstreams(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.Upstream> items) {
    for (io.fabric8.openshift.api.model.operator.v1.Upstream item : items) {io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(item);_visitables.get("upstreams").remove(builder);if (this.upstreams != null) {this.upstreams.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromUpstreams(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> predicate) {
    if (upstreams == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> each = upstreams.iterator();
    final List visitables = _visitables.get("upstreams");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildUpstreams instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.Upstream> getUpstreams() {
    return build(upstreams);
  }
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.Upstream> buildUpstreams() {
    return build(upstreams);
  }
  public io.fabric8.openshift.api.model.operator.v1.Upstream buildUpstream(java.lang.Integer index) {
    return this.upstreams.get(index).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.Upstream buildFirstUpstream() {
    return this.upstreams.get(0).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.Upstream buildLastUpstream() {
    return this.upstreams.get(upstreams.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.Upstream buildMatchingUpstream(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder item: upstreams) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingUpstream(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder item: upstreams) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withUpstreams(java.util.List<io.fabric8.openshift.api.model.operator.v1.Upstream> upstreams) {
    if (this.upstreams != null) { _visitables.get("upstreams").removeAll(this.upstreams);}
    if (upstreams != null) {this.upstreams = new java.util.ArrayList(); for (io.fabric8.openshift.api.model.operator.v1.Upstream item : upstreams){this.addToUpstreams(item);}} else { this.upstreams = null;} return (A) this;
  }
  public A withUpstreams(io.fabric8.openshift.api.model.operator.v1.Upstream... upstreams) {
    if (this.upstreams != null) {this.upstreams.clear();}
    if (upstreams != null) {for (io.fabric8.openshift.api.model.operator.v1.Upstream item :upstreams){ this.addToUpstreams(item);}} return (A) this;
  }
  public java.lang.Boolean hasUpstreams() {
    return upstreams != null && !upstreams.isEmpty();
  }
  public A addNewUpstream(java.lang.String address,java.lang.Integer port,java.lang.String type) {
    return (A)addToUpstreams(new Upstream(address, port, type));
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> addNewUpstream() {
    return new io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluentImpl.UpstreamsNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> addNewUpstreamLike(io.fabric8.openshift.api.model.operator.v1.Upstream item) {
    return new io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluentImpl.UpstreamsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> setNewUpstreamLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.Upstream item) {
    return new io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluentImpl.UpstreamsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> editUpstream(java.lang.Integer index) {
    if (upstreams.size() <= index) throw new RuntimeException("Can't edit upstreams. Index exceeds size.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> editFirstUpstream() {
    if (upstreams.size() == 0) throw new RuntimeException("Can't edit first upstreams. The list is empty.");
    return setNewUpstreamLike(0, buildUpstream(0));
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> editLastUpstream() {
    int index = upstreams.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last upstreams. The list is empty.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  public io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<A> editMatchingUpstream(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder> predicate) {
    int index = -1;
    for (int i=0;i<upstreams.size();i++) { 
    if (predicate.test(upstreams.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching upstreams. No match found.");
    return setNewUpstreamLike(index, buildUpstream(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UpstreamResolversFluentImpl that = (UpstreamResolversFluentImpl) o;
    if (policy != null ? !policy.equals(that.policy) :that.policy != null) return false;
    if (upstreams != null ? !upstreams.equals(that.upstreams) :that.upstreams != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(policy,  upstreams,  additionalProperties,  super.hashCode());
  }
  public class UpstreamsNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.UpstreamFluentImpl<io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<N>> implements io.fabric8.openshift.api.model.operator.v1.UpstreamResolversFluent.UpstreamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    UpstreamsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.Upstream item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(this, item);
    }
    UpstreamsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.UpstreamBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) UpstreamResolversFluentImpl.this.setToUpstreams(index,builder.build());
    }
    public N endUpstream() {
      return and();
    }
    
  }
  
}
